@@ -131,7 +131,6 @@ typedef struct nghttp3_stream_read_state {
 typedef enum nghttp3_stream_http_state {
   NGHTTP3_HTTP_STATE_NONE,
   NGHTTP3_HTTP_STATE_REQ_INITIAL,
-  NGHTTP3_HTTP_STATE_REQ_BEGIN,
   NGHTTP3_HTTP_STATE_REQ_HEADERS_BEGIN,
   NGHTTP3_HTTP_STATE_REQ_HEADERS_END,
   NGHTTP3_HTTP_STATE_REQ_DATA_BEGIN,
@@ -140,7 +139,6 @@ typedef enum nghttp3_stream_http_state {
   NGHTTP3_HTTP_STATE_REQ_TRAILERS_END,
   NGHTTP3_HTTP_STATE_REQ_END,
   NGHTTP3_HTTP_STATE_RESP_INITIAL,
-  NGHTTP3_HTTP_STATE_RESP_BEGIN,
   NGHTTP3_HTTP_STATE_RESP_HEADERS_BEGIN,
   NGHTTP3_HTTP_STATE_RESP_HEADERS_END,
   NGHTTP3_HTTP_STATE_RESP_DATA_BEGIN,
